## Authenticating Adapter for DB Mongo Adapter 

This document will go through the steps for authenticating the Adapter for DB Mongo adapter with Basic Authentication. Properly configuring the properties for an adapter in IAP is critical for getting the adapter online. You can read more about adapter authentication <a href="https://www.itential.com/automation-platform/integrations/adapters-resources/authentication/" target="_blank">HERE</a>. 

### Basic Authentication
The Adapter for DB Mongo adapter requires Basic Authentication. If you change authentication methods, you should change this section accordingly and merge it back into the adapter repository.

STEPS  
1. Ensure you have access to an Adapter for Mongo DB server and that it is running
2. Follow the steps in the README.md to import the adapter into IAP if you have not already done so
3. Use the properties below for a cluster set up. Tweak the properties as needed for your set up.
```json
    "properties": {
      "db": "<databaseName>",
      "host": "host1:27017,host2:27017,host3",
      "port": 27017,
      "createUuid": true,
      "databaseConnection": "connect on startup",
      "credentials": {
        "dbAuth": true,
        "dbAuthSource": "admin",
        "passwd": "<password>",
        "user": "<username>"
      },
      "ssl": {
        "enabled": true,
        "sslValidate": true,
        "sslCA": "/home/dirA/dirB/myCAFile.cert",
        "acceptInvalidCerts": true,
        "checkServerIdentity": true
      },
      "replSet": {
        "enabled": true,
        "replicaSet": "replicaSet=rs1"
      }
    }
```
4. Restart the adapter. If your properties were set correctly, the adapter should go online. 

### Troubleshooting
- Make sure you copied over the correct username and password.
- Turn on debug level logs for the adapter in IAP Admin Essentials.
- Turn on auth_logging for the adapter in IAP Admin Essentials (adapter properties).
- Investigate the logs - in particular:
  - The FULL REQUEST log to make sure the proper headers are being sent with the request.
  - The FULL BODY log to make sure the payload is accurate.
  - The CALL RETURN log to see what the other system is telling us.
- Remember when you are done to turn auth_logging off as you do not want to log credentials.
